@@ -6,7 +6,7 @@ import requests
 import structlog
 from urllib3.exceptions import InsecureRequestWarning
 
-from http_noah.common import ClientOptions, FormData, JSONData, Timeout, UploadFile
+from http_noah.common import BasicAuth, ClientOptions, FormData, JSONData, Timeout, UploadFile
 from http_noah.sync_client import ConnectionError, HTTPError, SyncAPIClientBase, SyncHTTPClient, TimeoutError
 
 from .common import TestClientBase, TestSSLClientBase, get_free_port
@@ -16,14 +16,36 @@ logger = structlog.get_logger(__name__)
 
 
 class TestSyncClient(TestClientBase):
+    client: SyncHTTPClient
+
     def setUp(self) -> None:
         self.client = SyncHTTPClient("localhost", self.server.port)
         super().setUp()
 
+    def tearDown(self) -> None:
+        self.client.close()
+        super().tearDown()
+
     def test_get_str(self) -> None:
         s = self.client.get("/str", response_type=str)
         self.assertEqual(s, "boo")
 
+    def test_get_bearer_protected_str(self) -> None:
+        with SyncHTTPClient("localhost", self.server.port) as client:
+            with self.assertRaisesRegex(HTTPError, "Forbidden"):
+                s = client.get("/bearer_protected_str", response_type=str)
+            client.set_auth_token("let-the-bear-in")
+            s = client.get("/bearer_protected_str", response_type=str)
+            self.assertEqual(s, "you have made it through")
+
+    def test_get_basic_protected_str(self) -> None:
+        with SyncHTTPClient("localhost", self.server.port) as client:
+            with self.assertRaisesRegex(HTTPError, "Forbidden"):
+                s = client.get("/basic_protected_str", response_type=str)
+            client.set_auth_basic(BasicAuth("emu", "wars"))
+            s = client.get("/basic_protected_str", response_type=str)
+            self.assertEqual(s, "you have made it through")
+
     def test_get_bytes(self) -> None:
         b = self.client.get("/bytes", response_type=bytes)
         self.assertEqual(b, b"bin-boo")
@@ -146,10 +168,10 @@ class TestSyncClient(TestClientBase):
 class TestSyncSSLClient(TestSSLClientBase):
     def test_disable_ssl_validation(self):
         options = ClientOptions(ssl_verify_cert=False)
-        client = SyncHTTPClient("localhost", self.server.port, scheme="https", options=options)
-        with self.assertWarns(InsecureRequestWarning):
-            s = client.get("/str", response_type=str)
-        self.assertEqual(s, "boo")
+        with SyncHTTPClient("localhost", self.server.port, scheme="https", options=options) as client:
+            with self.assertWarns(InsecureRequestWarning):
+                s = client.get("/str", response_type=str)
+            self.assertEqual(s, "boo")
 
     def test_requires_ssl_validation(self):
         with SyncHTTPClient("localhost", self.server.port, scheme="https") as client:
